@@ -1,4 +1,4 @@
-# $Id: Generator.pm 17 2005-08-17 05:05:21Z daisuke $
+# $Id: Generator.pm 18 2005-08-17 10:20:53Z daisuke $
 #
 # Copyright (c) 2005 Daisuke Maki <dmaki@cpan.org>
 # All rights reserved.
@@ -12,10 +12,14 @@ sub set_values
 {
     my $self  = shift;
     my $rss   = shift;
+    my $local = shift;
     my %args  = @_;
 
     while (my($key, $value) = each %args) {
-        $rss->{$key} = $value;
+        $local->{$key} = $value;
+        if (my $ns = $rss->{_namespaces}{$key}) {
+            $local->{$ns} = $value;
+        }
     }
 }
 
@@ -23,21 +27,25 @@ sub channel
 {
     my $self = shift;
     my $rss  = shift;
-    $self->set_values($rss->{channel}, @_)
+    $rss->{channel} ||= {};
+    $self->set_values($rss, $rss->{channel}, @_);
 }
 
 sub image
 {
     my $self = shift;
     my $rss  = shift;
-    $self->set_values($rss->{image}, @_)
+
+    $rss->{image} ||= {};
+    $self->set_values($rss, $rss->{image}, @_)
 }
 
 sub textinput
 {
     my $self = shift;
     my $rss  = shift;
-    $self->set_values($rss->{textinput}, @_)
+    $rss->{textinput} ||= {};
+    $self->set_values($rss, $rss->{textinput}, @_)
 }
 
 sub add_item
@@ -46,9 +54,9 @@ sub add_item
     my $rss  = shift;
 
     my $item = {};
-    $self->set_values($item, @_);
-
+    $self->set_values($rss, $item, @_);
     $rss->{items} ||= [];
+
     push @{$rss->{items}}, $item;
 }
 
